Installation
============

Automatic installation
----------------------

.. code-block:: bash

    $ pip install django-tornado-websockets

    # In your Django project
    $ python manage.py collectstatic

Manual installation
-------------------

.. code-block:: bash

    $ git clone --recursive https://github.com/Kocal/django-tornado-websockets.git
    $ cd django-tornado-websockets
    $ python setup.py install

    # In your Django project
    $ python manage.py collectstatic